description property

String? get description

Returns the description of the enum field.

If the description is null, the doc comment of the enum field is returned.

Implementation

String? get description {
  return maybeMap(
    orElse: null,
    camel: '''
convert to a string with the separators denoted
by having the next letter capitalized
''',
    constant: '''
convert to an upper case, underscore separated string
''',
    dot: '''
convert to a lower case period separated string
''',
    kebab: '''
Convert to a lower case, dash separated string
''',
    lowerFirst: '''
convert to a string with the first character lower cased
''',
    no: '''
Convert the string without any casing (lower case, space separated)
''',
    pascal: '''
Convert to a string denoted in the same fashion as [camel]
but with the first letter capitalized
''',
    path: '''
Convert to a lower case, slash separated string
''',
    sentence: '''
Convert to a lower case, space separated string
''',
    snake: '''
Convert to a lower case, underscore separated string
''',
    swap: '''
Convert to a string with every character case reversed
''',
    title: '''
convert to a space spearated string with the
first character of every word uppercased
''',
    upperFirst: '''
Convert to a string with the first character upper cased
''',
    capital: '''
Converts to a captialized word, space separated string
of every word
''',
    header: '''
Converts to a captialized word, dash separated string
''',
    sponge: '''
Converts to a string with every character randomly lowercased/capitalized
''',
  );
}